@@ -1,24 +1,31 @@
-from django.conf import settings
-from django.contrib.sites.models import Site
-from django.contrib.admin.views.main import ChangeList, ALL_VAR, IS_POPUP_VAR,\
-    ORDER_TYPE_VAR, ORDER_VAR, SEARCH_VAR
-from cms.models import Title, PagePermission, Page, PageModerator
-from cms.utils import get_language_from_request, find_children
-from cms.utils.permissions import get_user_sites_queryset
+# -*- coding: utf-8 -*-
 from cms.exceptions import NoHomeFound
-from cms.models.moderatormodels import MASK_PAGE, MASK_CHILDREN,\
+from cms.models import Title, Page, PageModerator
+from cms.models.moderatormodels import MASK_PAGE, MASK_CHILDREN, \
     MASK_DESCENDANTS, PageModeratorState
+from cms.utils.permissions import get_user_sites_queryset
+from django.conf import settings
+from django.contrib.admin.views.main import ChangeList, ALL_VAR, IS_POPUP_VAR, \
+    ORDER_TYPE_VAR, ORDER_VAR, SEARCH_VAR
+from django.contrib.sites.models import Site
+from menus.utils import find_children
 
 
 
 COPY_VAR = "copy"
 
 class CMSChangeList(ChangeList):
+    '''
+    Renders a Changelist - In our case it looks like a tree - it's the list of
+    *instances* in the Admin.
+    It is usually responsible for pagination (not here though, we have a 
+    treeview)
+    '''
     real_queryset = False
     
     def __init__(self, request, *args, **kwargs):
         super(CMSChangeList, self).__init__(request, *args, **kwargs)
-        from cms.admin.utils import current_site
+        from cms.utils.plugins import current_site
         self._current_site = current_site(request)
         try:
             self.query_set = self.get_query_set(request)
@@ -26,8 +33,8 @@ class CMSChangeList(ChangeList):
             raise
         self.get_results(request)
         
-        
-        request.session['cms_admin_site'] = self._current_site.pk
+        if self._current_site:
+            request.session['cms_admin_site'] = self._current_site.pk
         self.set_sites(request)
         
     def get_query_set(self, request=None):
@@ -47,7 +54,7 @@ class CMSChangeList(ChangeList):
         return qs
     
     def is_filtered(self):
-        from cms.admin.utils import SITE_VAR
+        from cms.utils.plugins import SITE_VAR
         lookup_params = self.params.copy() # a dictionary of the query string
         for i in (ALL_VAR, ORDER_VAR, ORDER_TYPE_VAR, SEARCH_VAR, IS_POPUP_VAR, SITE_VAR):
             if i in lookup_params:
@@ -65,15 +72,18 @@ class CMSChangeList(ChangeList):
                 self.full_result_count = self.root_query_set.count()
     
     def set_items(self, request):
-        lang = get_language_from_request(request)
         site = self._current_site
+        # Get all the pages, ordered by tree ID (it's convenient to build the 
+        # tree using a stack now)
         pages = self.get_query_set(request).drafts().order_by('tree_id', 'parent', 'lft').select_related()
         
+        # Get lists of page IDs for which the current user has 
+        # "permission to..." on the current site. 
         perm_edit_ids = Page.permissions.get_change_id_list(request.user, site)
         perm_publish_ids = Page.permissions.get_publish_id_list(request.user, site)
         perm_advanced_settings_ids = Page.permissions.get_advanced_settings_id_list(request.user, site)
         perm_change_list_ids = Page.permissions.get_change_id_list(request.user, site)
-
+        
         if perm_edit_ids and perm_edit_ids != Page.permissions.GRANT_ALL:
             pages = pages.filter(pk__in=perm_edit_ids)
             #pages = pages.filter(pk__in=perm_change_list_ids)   
@@ -85,7 +95,7 @@ class CMSChangeList(ChangeList):
             
             # get all moderations for current user and all pages
             pages_moderator_set = PageModerator.objects \
-                .filter(user=request.user, page__site__id=self._current_site.pk) \
+                .filter(user=request.user, page__site=self._current_site) \
                 .values_list('page', 'moderate_page', 'moderate_children', 'moderate_descendants')
             # put page / moderations into singe dictionary, where key is page.id 
             # and value is sum of moderations, so if he can moderate page and descendants
@@ -149,7 +159,7 @@ class CMSChangeList(ChangeList):
                 page.menu_level = 0
                 root_pages.append(page)
                 if page.parent_id:
-                    page.get_cached_ancestors()
+                    page.get_cached_ancestors(ascending=True)
                 else:
                     page.ancestors_ascending = []
                 page.home_pk_cache = home_pk
