@@ -1,13 +1,14 @@
+# -*- coding: utf-8 -*-
 from cms.models.managers import BasicPagePermissionManager, \
     PagePermissionManager
 from cms.models.moderatormodels import ACCESS_CHOICES, \
     ACCESS_PAGE_AND_DESCENDANTS
 from cms.models.pagemodel import Page
+from cms.utils.helpers import reversion_register
 from django.contrib.auth.models import User, Group
 from django.contrib.sites.models import Site
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
-from cms.utils.helpers import reversion_register
 
 class AbstractPagePermission(models.Model):
     """Abstract page permissions
@@ -38,11 +39,11 @@ class AbstractPagePermission(models.Model):
         targets = filter(lambda item: item, (self.user, self.group,))
         return ", ".join([unicode(t) for t in targets]) or 'No one'
     
-    def save(self, force_insert=False, force_update=False):
+    def save(self, *args, **kwargs):
         if not self.user and not self.group:
             # don't allow `empty` objects
             return
-        return super(AbstractPagePermission, self).save(force_insert, force_update)    
+        return super(AbstractPagePermission, self).save(*args, **kwargs)    
 
     
 class GlobalPagePermission(AbstractPagePermission):
