@@ -1,8 +1,9 @@
+from django.conf import settings
 from cms.plugin_pool import plugin_pool
 from cms.plugin_base import CMSPluginBase
 from django.utils.translation import ugettext_lazy as _
 from cms.plugins.googlemap.models import GoogleMap
-from cms.plugins.googlemap.settings import GOOGLE_MAPS_API_KEY
+from django.forms.widgets import Media
 
 class GoogleMapPlugin(CMSPluginBase):
     model = GoogleMap
@@ -10,15 +11,13 @@ class GoogleMapPlugin(CMSPluginBase):
     render_template = "cms/plugins/googlemap.html"
     
     def render(self, context, instance, placeholder):
-        if 'GOOGLE_MAPS_API_KEY' in context:
-            key = context['GOOGLE_MAPS_API_KEY']
-        else:
-            key = GOOGLE_MAPS_API_KEY
         context.update({
             'object':instance, 
             'placeholder':placeholder, 
-            'GOOGLE_MAPS_API_KEY':key
         })
         return context
- 
+    
+    def get_plugin_media(self, request, context, plugin):
+        return Media(js = ('http://maps.google.com/maps/api/js?sensor=true',))
+
 plugin_pool.register_plugin(GoogleMapPlugin)
\ No newline at end of file
